@@ -33,7 +33,7 @@
 #include <vdk/vdkutils.h>
 #include <vdk/rawobj.h>
 #include <vdk/vdkprops.h>
-#include <vdk/vdkstring.h>
+#include <vdk/vdkustring.h>
 
 #ifdef USE_SIGCPLUSPLUS
 #     include <vdk/sigc_addon.h>
@@ -73,10 +73,9 @@ class VDKObjectSignalUnit
 public:
     void* owner;
     void* obj;
-    VDKString signal;
-    VDKObjectSignalUnit(void* owner,void *obj, char* signal):
-        owner(owner),obj(obj),signal(signal) {}
-    ~VDKObjectSignalUnit() {}
+    VDKUString signal;
+    VDKObjectSignalUnit(void* owner,void *obj, char* signal);
+    ~VDKObjectSignalUnit();
 };
 /*!
   Object connected signal list
@@ -93,10 +92,9 @@ class VDKObjectEventUnit
 public:
     void* owner;
     void* obj;
-    VDKString signal;
-    VDKObjectEventUnit(void* owner,void *obj, char* signal):
-        owner(owner),obj(obj),signal(signal) {}
-    ~VDKObjectEventUnit() {}
+    VDKUString signal;
+    VDKObjectEventUnit(void* owner,void *obj, char* signal);
+    ~VDKObjectEventUnit();
 };
 /*!
   Object connected event list
@@ -114,10 +112,11 @@ typedef VDKReadWriteValueProp<VDKObject,VDKPoint> SizeOProp;
 class SizeObjectProp: public SizeOProp
 {
 public:
-    SizeObjectProp(){}
+    SizeObjectProp();
     SizeObjectProp(char* name, VDKObject* object,
                    void (VDKObject::*write)(VDKPoint) =  NULL,
-                   VDKPoint (VDKObject::*read)(void) = NULL) : SizeOProp(name,object,VDKPoint(0,0),write,read) {}
+                   VDKPoint (VDKObject::*read)(void) = NULL);
+    ~SizeObjectProp();
     void operator = (VDKPoint);
     operator VDKPoint();
 };
@@ -159,6 +158,7 @@ class VDKObject : public SigC::Object, public VDKNotCopyAble
   VDKReadWriteValueProp<VDKObject,VDKRgb> ActiveBackground;
   VDKReadWriteValueProp<VDKObject,VDKRgb> SelectedBackground;
   VDKReadWriteValueProp<VDKObject,VDKRgb> Foreground;
+  //VDKReadWriteValueProp<VDKObject,VDKRgb> BaseColor;
   /*!
     Setting this property will set the object font.
 
@@ -174,8 +174,94 @@ class VDKObject : public SigC::Object, public VDKNotCopyAble
     Setting this property will set/get object sensitivity. 
    */
   VDKReadWriteValueProp<VDKObject,bool> Enabled;
+  /*!
+    Setting this property will get object focus.
+   */
+  VDKReadOnlyValueProp<VDKObject,bool> HasFocus;
   /*!
     Setting this property will set/get object cursor type.
+    VDKCursorType and its GdkCursorType value (updated 2005/11/08) :\n
+	curDefault = Default cursor\n
+	curXCursor = GDK_X_CURSOR\n
+	curArrow = GDK_ARROW\n
+	curArrowDown = GDK_BASED_ARROW_DOWN\n
+	curArrowUp = GDK_BASED_ARROW_UP\n
+	curBoat = GDK_BOAT\n
+	curBogosity = GDK_BOGOSITY\n
+	curBottomLeftCorner = GDK_BOTTOM_LEFT_CORNER\n
+	curBottomRightCorner = GDK_BOTTOM_RIGHT_CORNER\n
+	curBottomSide = GDK_BOTTOM_SIDE\n
+	curBottomTee = GDK_BOTTOM_TEE\n
+	curBoxSpiral = GDK_BOX_SPIRAL\n
+	curCenterPtr = GDK_CENTER_PTR\n
+	curCircle = GDK_CIRCLE\n
+	curClock = GDK_CLOCK\n
+	curCoffeeMug = GDK_COFFEE_MUG\n
+	curCross = GDK_CROSS\n
+	curCrossReverse = GDK_CROSS_REVERSE\n
+	curCrossHair = GDK_CROSSHAIR\n
+	curDiamondCross = GDK_DIAMOND_CROSS\n
+	curDot = GDK_DOT\n
+	curDotBox = GDK_DOTBOX\n
+	curDoubleArrow = GDK_DOUBLE_ARROW\n
+	curDraftLarge = GDK_DRAFT_LARGE\n
+	curDraftSmall = GDK_DRAFT_SMALL\n
+	curDrapedBox = GDK_DRAPED_BOX\n
+	curExchange = GDK_EXCHANGE
+	curFleur = GDK_FLEUR,\n
+	curGobbler = GDK_GOBBLER\n
+	curGumby = GDK_GUMBY\n
+	curHand1 = GDK_HAND1\n
+	curHandPtr = GDK_HAND2\n
+	curHeart = GDK_HEART\n
+	curIcon = GDK_ICON\n
+	curIronCross = GDK_IRON_CROSS\n
+	curLeftPtr = GDK_LEFT_PTR\n
+	curLeftSide = GDK_LEFT_SIDE\n
+	curLeftTee = GDK_LEFT_TEE\n
+	curLeftButton = GDK_LEFTBUTTON\n
+	curLLAngle = GDK_LL_ANGLE\n
+	curLRAngle = GDK_LR_ANGLE\n
+	curMan = GDK_MAN\n
+	curMiddleButton = GDK_MIDDLEBUTTON\n
+	curMouse = GDK_MOUSE\n
+	curPencil = GDK_PENCIL\n
+	curPirate = GDK_PIRATE\n
+	curPlus = GDK_PLUS\n
+	curQuestionArrow = GDK_QUESTION_ARROW\n
+	curRightPtr = GDK_RIGHT_PTR\n
+	curRightSide = GDK_RIGHT_SIDE\n
+	curRightTee = GDK_RIGHT_TEE\n
+	curRightButton = GDK_RIGHTBUTTON\n
+	curRTLLogo = GDK_RTL_LOGO\n
+	curSailBoat = GDK_SAILBOAT\n
+	curSBDownArrow = GDK_SB_DOWN_ARROW\n
+	curSBHDoubleArrow = GDK_SB_H_DOUBLE_ARROW\n
+	curSBLeftArrow = GDK_SB_LEFT_ARROW\n
+	curSBRightArrow = GDK_SB_RIGHT_ARROW\n
+	curSBUpArrow = GDK_SB_UP_ARROW\n
+	curSBVDoubleArrow = GDK_SB_V_DOUBLE_ARRO\n,
+	curShuttle = GDK_SHUTTLE\n
+	curSizing = GDK_SIZING\n
+	curSpider = GDK_SPIDER\n
+	curSprayCan = GDK_SPRAYCAN\n
+	curStar = GDK_STAR\n
+	curTarget = GDK_TARGET\n
+	curTCross = GDK_TCROSS\n
+	curTopLeftArrow = GDK_TOP_LEFT_ARROW\n
+	curTopLeftCorner = GDK_TOP_LEFT_CORNER\n
+	curTopRightCorner = GDK_TOP_RIGHT_CORNER\n
+	curTopSide = GDK_TOP_SIDE\n
+	curTopTee = GDK_TOP_TEE\n
+	curTrek = GDK_TREK\n
+	curULAngle = GDK_UL_ANGLE\n
+	curUmbrella = GDK_UMBRELLA\n
+	curURAngle = GDK_UR_ANGLE\n
+	curWatch = GDK_WATCH\n
+	curXTerm = GDK_XTERM\n
+	curLastCursor = GDK_LAST_CURSOR\n
+	curIsPixmap = GDK_CURSOR_IS_PIXMAP\n
+	See GDK API documentation for details on cursors image
    */
   VDKReadWriteValueProp<VDKObject,VDKCursorType> Cursor;
   /*!
@@ -186,31 +272,19 @@ class VDKObject : public SigC::Object, public VDKNotCopyAble
 
 // GTK_STATE_NORMAL = 0, GTK_STATE_ACTIVE, GTK_STATE_PRELIGHT,
   // GTK_STATE_SELECTED,GTK_STATE_INSENSITIVE
-  void SetNormalBackground(VDKRgb c) {
-      SetBackground(c,GTK_STATE_NORMAL);
-  }
-  void SetPrelightBackground(VDKRgb c) {
-      SetBackground(c,GTK_STATE_PRELIGHT);
-  }
-  void SetInsensitiveBackground(VDKRgb c) {
-      SetBackground(c,GTK_STATE_INSENSITIVE);
-  }
-  void SetActiveBackground(VDKRgb c) {
-      SetBackground(c,GTK_STATE_ACTIVE);
-  }
-  void SetSelectedBackground(VDKRgb c) {
-      SetBackground(c,GTK_STATE_SELECTED);
-  }
+  void SetNormalBackground(VDKRgb c);
+  void SetPrelightBackground(VDKRgb c);
+  void SetInsensitiveBackground(VDKRgb c);
+  void SetActiveBackground(VDKRgb c);
+  void SetSelectedBackground(VDKRgb c);
   /*!
     Gets object background color
    */
-  VDKRgb
-    GetBackground(GtkStateType state = GTK_STATE_NORMAL);
+  VDKRgb GetBackground(GtkStateType state = GTK_STATE_NORMAL);
   /*!
     Gets object foreground color
    */
-  VDKRgb
-    GetForeground(GtkStateType state = GTK_STATE_NORMAL);
+  VDKRgb GetForeground(GtkStateType state = GTK_STATE_NORMAL);
 
 private:
   /*
@@ -253,7 +327,7 @@ protected:
     VDKObject* parent;
     /*! \internal
      */
-    static void VDKEventPipe(GtkWidget* w, GdkEvent* event, void* obj);
+    static int VDKEventPipe(GtkWidget* w, GdkEvent* event, void* obj);
     /*! \internal
      */
     void _setBackground_(GtkWidget* wid,
@@ -304,13 +378,11 @@ public:
     /*!
       returns an enum id (incomplete and not so useful)
     */
-    virtual int isA() { return object_class; }
+    virtual int isA();
     /*!
       Returns object owner form.
      */
-    VDKForm* Owner() {
-        return owner;
-    }
+    VDKForm* Owner();
     /*!
       Returns underlying GTK+ widget.
      */
@@ -339,10 +411,7 @@ public:
     /*!
       Gets object font
     */
-    VDKFont* GetFont() 
-      {
-        return Font;
-      }
+    VDKFont* GetFont();
     /*!
       Set object visibility
       \param visible either true or false
@@ -351,10 +420,7 @@ public:
     /*!
       Returns object visibility
     */
-    bool GetVisible() 
-      {
-        return GTK_WIDGET_VISIBLE(widget);
-      }
+    bool GetVisible();
     /*!
       Sets object assigned cursor
     */
@@ -362,10 +428,7 @@ public:
     /*!
       Gets object assigned cursor
     */
-    VDKCursorType     GetCursor() 
-      {
-        return Cursor;
-      }
+    VDKCursorType GetCursor();
     /*!
       Sets object foreground
       \param   color a VDKRgb object
@@ -374,10 +437,7 @@ public:
     virtual void SetForeground(VDKRgb color,
                                GtkStateType state = GTK_STATE_NORMAL);
 
-    void SetNormalForeground(VDKRgb color) 
-      {
-        SetForeground(color);
-      }
+    void SetNormalForeground(VDKRgb color);
     /*!
       Sets object background
       \param   color a VDKRgb object
@@ -390,20 +450,13 @@ public:
       \param   w width
       \param   h height
      */
-    void SetSize(int w, int h) 
-      {
-        if(GTK_IS_WIDGET(widget))
-	  gtk_widget_set_usize(GTK_WIDGET(widget),w,h);
-      }
+    void SetSize(int w, int h);
     /*!
       Sets object minimum size
       \param   s, a VDKPoint object
      */
       
-    void SetUsize(VDKPoint s) 
-      {
-        SetSize(s.X(),s.Y());
-      }
+    void SetUsize(VDKPoint s);
     /*
       Sets/unsets object sensitivity
       \param   flag, either true or false
@@ -413,16 +466,13 @@ public:
     /*
       Returns if the object is enable or not
     */
-    bool GetEnabled() 
-      {
-        return Enabled;
-      }
+    bool GetEnabled();
     /*!
       Sets object tip.
      */
-    virtual void SetTip(char* );
+    virtual void SetTip(const char* );
     /*!
-      Add on abiect to the object.
+      Add on object to the object.
       \param obj the object to be added
       \param justify where the object wil be added, can be:
       - l_justify packed to end (appended)
@@ -432,29 +482,20 @@ public:
       \param padding how many pixels are left around object
     */
     virtual void Add(VDKObject* obj, int justify = l_justify,
-                     int expand = TRUE, int fill = TRUE ,
+                     int expand = true, int fill = true,
                      int padding = 0);
     /*!
       Return contained objects list
      */
-    ItemList& Items() 
-      {
-        return items;
-      }
+    ItemList& Items();
     /*!
       \internal
     */
-    ItemList& Garbages() 
-      {
-        return garbages;
-      }
+    ItemList& Garbages();
     /*!
       \internal
     */
-    RawList& Raws() 
-      {
-        return raws;
-      }
+    RawList& Raws();
     /*!
       Draw an object
     */
@@ -479,9 +520,7 @@ public:
       Emit a signal directly to parent (static tables)
       \param signal
     */
-    void SignalEmitParent(int signal) {
-        SignalEmit(signal,Parent_level);
-    }
+    void SignalEmitParent(int signal);
     /*!
       Emit a signal directly to parent (dynamic tables)
       \param signal
@@ -490,7 +529,11 @@ public:
     /*!
       Grab the focus to itself
      */
-    void GrabFocus();
+    virtual void GrabFocus();
+    /*!
+      Grab the focus to itself
+     */
+    virtual bool isFocused();
     /*!
       \internal
     */    
@@ -509,9 +552,7 @@ public:
     /*!
       Sets object parenthood
     */
-    VDKObject* Parent(VDKObject* p = NULL) {
-        if(p) parent = p; return parent;
-    }
+    VDKObject* Parent(VDKObject* p = NULL);
     // signal and events default dispatchers for class level
     /*!
       \internal
@@ -520,43 +561,19 @@ public:
     /*!
       \internal
     */
-    virtual int VDKObjectSignalResponse(GtkWidget* , int , void*, bool) 
-      {
-        return FALSE;
-      }
+    virtual int VDKObjectSignalResponse(GtkWidget* , int , void*, bool);
     /*!
       \internal
     */
-    virtual int VDKObjectEventResponse(GtkWidget* , GdkEvent*, void*, bool) 
-      {
-        return FALSE;
-      }
+    virtual int VDKObjectEventResponse(GtkWidget* , GdkEvent*, void*, bool);
 
-    virtual int ObjectSignalDetach(int , int ) 
-      {
-        return -1;
-      }
-    virtual bool ObjectSignalAttach(int ) 
-      {
-        return false;
-      }
-    virtual int ObjectEventDetach(VDKEvent ) 
-      {
-        return -1;
-      }
-    virtual bool ObjectEventAttach(int ) 
-      {
-        return false;
-      }
+    virtual int ObjectSignalDetach(int , int );
+    virtual bool ObjectSignalAttach(int );
+    virtual int ObjectEventDetach(VDKEvent );
+    virtual bool ObjectEventAttach(int );
  protected:
-     virtual int VDKObjectSignalResponseTableSize() 
-       {
-         return 0;
-       }
-     virtual int VDKObjectEventResponseTableSize() 
-       {
-         return 0;
-       }
+     virtual int VDKObjectSignalResponseTableSize();
+     virtual int VDKObjectEventResponseTableSize();
   /*
    */
   // signal and events default dispatchers for parent level
@@ -564,48 +581,24 @@ public:
     /*!
       \internal
     */
-    virtual int VDKSignalResponse(GtkWidget* , int , void*, void *, bool) 
-      {
-        return 0;
-      }
+    virtual int VDKSignalResponse(GtkWidget* , int , void*, void *, bool);
     /*!
       \internal
     */
-    virtual int VDKEventResponse(GtkWidget* , GdkEvent* , void*, void*, bool )
-      {
-        return 0;
-      }
-    virtual int SignalDetach(VDKObject* , int ) 
-      {
-        return -1;
-      }
-    virtual bool SignalAttach(int ) 
-      {
-        return false;
-      }
-    virtual int EventDetach(VDKObject* ,VDKEvent ) 
-      {
-        return -1;
-      }
-    virtual bool EventAttach(int ) 
-      {
-        return false;
-      }
+    virtual int VDKEventResponse(GtkWidget* , GdkEvent* , void*, void*, bool );
+    virtual int SignalDetach(VDKObject* , int );
+    virtual bool SignalAttach(int );
+    virtual int EventDetach(VDKObject* ,VDKEvent );
+    virtual bool EventAttach(int );
 protected:
     /*!
       \internal
     */
-    virtual int VDKSignalResponseTableSize() 
-      {
-        return 0;
-      }
+    virtual int VDKSignalResponseTableSize();
     /*!
       \internal
     */
-    virtual int VDKEventResponseTableSize() 
-      {
-        return 0;
-      }
+    virtual int VDKEventResponseTableSize();
   /*
 ==================== signal management ala Gtk+ ======================
   */
@@ -628,10 +621,7 @@ public:
 		      char* signal,
 		      bool (VDKObject::*method)(VDKObject*), 
 		      bool gtk = true,
-		      bool after = false) 
-      {
-        return -1;
-      }
+		      bool after = false);
     /*!
       Placeholder for subclasses, at this level does nothing.
       Connects <this>-signal to a <this> method
@@ -648,39 +638,25 @@ public:
     int SignalConnect(char* signal ,
 		      bool (VDKObject::*method)(VDKObject*), 
 		      bool gtk = true,
-		      bool after = false) 
-      {
-        return -1;
-      }
+		      bool after = false);
    // general signal unit response (at this level simply answer false)
-    virtual int VDKSignalUnitResponse(GtkWidget* , char* , void*) 
-      {
-        return 0;
-      }
+    virtual int VDKSignalUnitResponse(GtkWidget* , char* , void*);
     /*! disconnect this from connection
       \param   connection must be achieved with a previous
       SignalConnect() call
       */
-    bool SignalDisconnect(int connection) 
-      {
-        return false;
-      }
+    bool SignalDisconnect(int connection);
   // find signal at class level
     /*!
       \internal
     */
-    virtual bool FindSignalAtClassLevel(VDKObject* , VDKString& ) 
-      {
-        return false;
-      }
+    virtual bool FindSignalAtClassLevel(VDKObject* , char* );
   // find signal at parent level
     /*!
       \internal
     */
-    virtual bool FindSignalAtParentLevel(VDKObject* , VDKString& ) 
-      {
-        return false;
-      }
+  //   virtual bool FindSignalAtParentLevel(VDKObject* , VDKUString& ) 
+    virtual bool FindSignalAtParentLevel(VDKObject* , char* );
 protected:
     // unique Gtk+ callback that redirects to
     // above VDKSignalUnitResponse()
@@ -695,22 +671,17 @@ public:
     /*!
       \internal
     */
-      virtual bool FindEventAtClassLevel(VDKObject* , VDKString& ) {
-          return false;
-      }
+  //  virtual bool FindEventAtClassLevel(VDKObject* , VDKUString& ) 
+  virtual bool FindEventAtClassLevel(VDKObject* , char* );
     /*!
       \internal
     */
-      virtual bool FindEventAtParentLevel(VDKObject* , VDKString& ) {
-          return false;
-      }
+  //  virtual bool FindEventAtParentLevel(VDKObject* , VDKUString& ) 
+  virtual bool FindEventAtParentLevel(VDKObject* , char* );
     /*!
       \internal
     */
-      virtual int  VDKEventUnitResponse(GtkWidget* , char* , 
-					GdkEvent* , void*) {
-          return 0;
-      }
+      virtual int  VDKEventUnitResponse(GtkWidget* , char* , GdkEvent* , void*);
     /*!
       Placeholder for subclasses, at this level does nothing.
       connects an object-event to a <this> method 
@@ -723,11 +694,7 @@ public:
       int EventConnect(VDKObject* obj, 
 		       char* event, 
 		       bool (VDKObject::*method) (VDKObject* , GdkEvent*), 
-		       bool after = false) 
-	{
-          return -1;
-      
-	}
+		       bool after = false);
       /*!
 	Placeholder for subclasses, at this level does nothing.
 	connects an <this>-event to a <this> method
@@ -737,53 +704,43 @@ public:
 	the "after" slot.
       */
       int EventConnect(char* , bool (VDKObject::*) (VDKObject* , GdkEvent*), 
-		       bool after = false) 
-	{
-          return -1;
-	}
+		       bool after = false);
       /*! disconnect this from connection
 	\param   connection must be achieved with a previous
 	EventConnect() call
       */
-      bool EventDisconnect(int connection) 
-	{
-          return false;
-	}
-      virtual int  VDKSignalResponseListSize() {
-          return 0;
-      }
+      bool EventDisconnect(int connection);
+      virtual int  VDKSignalResponseListSize();
+      
 protected:
     // unique Gtk+ callback that redirects to
     // above VDKEventUnitResponse()
     /*!
       \internal
     */
-    static void VDKEventUnitPipe(GtkWidget* , GdkEvent*, void* );
+    static int VDKEventUnitPipe(GtkWidget* , GdkEvent*, void* );
+
 #ifdef USE_SIGCPLUSPLUS
  public:
-    VDKSignal1<void, char*> OnKeyPress;  // deprecated !!
-    VDKSignal1<void, char*> OnKeyRelease;//     "
-
+   /** The signal for raw GdkEvents* */
     VDKRawEventSignal     OnRawEvent;
-
+   /** The signal responsible for button events */
     VDKButtonSignal       OnButtonEvent;
+   /** The signal responsible for keystroke events */ 
     VDKKeySignal          OnKeyEvent;
+   /** The signal responsible for changes in key focus */
     VDKKeyFocusSignal     OnKeyFocusEvent;
+   /** The signal responsible for changes in pointer focus */
     VDKPointerFocusSignal OnPointerFocusEvent;
+   /** The signal responsible for pointer (mouse) events */
     VDKPointerSignal      OnPointerEvent;
+   /** The signal responsible for map events */
      VDKMapSignal         OnMapEvent;
+   /** The signal responsible for geometry events */
      VDKGeometrySignal    OnGeometryEvent;
+   /** The signal responsible for paint events */
      VDKPaintSignal       OnPaintEvent;
- protected:
-    // will be overriden in some subclasses, but there is no need to make
-    // it 'virtual'.
-    static void make_gtksigc_connection(VDKObject* obj);
- private:
-    static void _handle_key_press(GtkWidget* wid, GdkEventKey *event,
-				  gpointer obj);
-    static void _handle_key_release(GtkWidget* wid, GdkEventKey *event,
-				    gpointer);
-#endif
+#endif // USE_SIGCPLUSPLUS
 };
 #endif
 
