@@ -253,7 +253,7 @@ EditorComponent::ScrollTo(const char* member)
 // get file extension
 char* get_extension(char* s)
 {
-  int t = std::strlen(s)-1;
+  int t = (int)(std::strlen(s)-1);
   char* p = &s[t];
   for(; (s != p) && (*p != '.') && (*p != '/'); p--) ;
   return ( s!= p)  && (*p != '/') ? p : static_cast<char*>(0);
