@@ -28,11 +28,14 @@
 #include "testvdk.h"
 #include <vdk/vdk.h>
 #include <vdk/vdkfilechooser.h>
+#if defined _WIN32 || defined _WIN64
+#else
 #include "vdk/FileDialog.h"
+#include "sigctest.h"
+#endif
 #include "chartcompo.h"
 #include "ctreecompo.h"
 #include "dnd.h"
-#include "sigctest.h"
 #include "canvascompo.h"
 #include "drawingcompo.h"
 #include "combocompo.h"
@@ -49,13 +52,13 @@ extern char * mini_cfolder_xpm[];
 */
 int main (int argc, char *argv[])
 {
-  // makes application
-  TestvdkApp app(&argc, argv);
-  // parse resource file
-  app.SetResourceFile("testvdkrc");
-  // runs application
-  app.Run();
-  return 0;
+	// makes application
+	TestvdkApp app(&argc, argv);
+	// parse resource file
+	app.SetResourceFile("testvdkrc");
+	// runs application
+	app.Run();
+	return 0;
 }
 
 // Testvdk MAIN FORM  CLASS
@@ -71,6 +74,7 @@ defining signal static table
 DEFINE_SIGNAL_MAP(TestvdkForm,VDKForm)
   ON_SIGNAL(quitMenu,activate_signal,OnquitMenuActivate),
   ON_SIGNAL(openMenu,activate_signal,OnopenMenuActivate),
+  ON_SIGNAL(MenuItem1,activate_signal,OnDockButtonClicked),
   ON_SIGNAL(filechooser,activate_signal,OnfilechooserActivate),
   ON_SIGNAL(testlist,row_activated_signal,OnTestIt),
   ON_SIGNAL(testlist,click_column_signal,OnTestIt),
@@ -79,7 +83,8 @@ DEFINE_SIGNAL_MAP(TestvdkForm,VDKForm)
   ON_SIGNAL(cbentry,changed_signal,OnComboEntryChanged),
   ON_SIGNAL(cbentry,focus_in_signal,OnComboEntryFocusIn),
   ON_SIGNAL(cbentry,focus_out_signal,OnComboEntryFocusOut),
-  ON_SIGNAL(chbox,toggled_signal,OnCheckBoxToggled)
+  ON_SIGNAL(chbox,toggled_signal,OnCheckBoxToggled),
+  ON_SIGNAL(dockbutton,clicked_signal,OnDockButtonClicked)
 END_SIGNAL_MAP
 
 /*
@@ -340,6 +345,7 @@ TestvdkForm::CreateSortedLists(VDKForm* owner)
   return box1;
   
 }
+
 /*
   answers on a double click on sorted lists
  */
@@ -371,21 +377,18 @@ TestvdkForm::OnSortedListSelect(VDKObject* sender)
 bool
 TestvdkForm::OnAddClicked(VDKObject* sender)
 {
-  if(sortedlist_widget)
-    {
-      ynad addr;
-      int t,z;
-      char p[10];
-      for(t = 0; t < 10;t++)
-	p[t] = (char) 64+rand()%26;
-      p[t] = '\0';
-      z = rand()%MAX_ADDR; 
-      addr.items[0] = p; 
-      for(t = 1; t <MAX_COL;t++)
-	addr.items[t] = address[z].items[t];
-      sortedlist_widget->AddKey(addr.items);
-    }
-  return true;
+	if (sortedlist_widget) {
+		ynad addr;
+		int t,z;
+		char p[10];
+		for (t = 0; t < 10; t++) p[t] = (char)(64+rand()%26);
+		p[t] = '\0';
+		z = rand()%MAX_ADDR;
+		addr.items[0] = p; 
+		for (t = 1; t < MAX_COL; t++) addr.items[t] = address[z].items[t];
+		sortedlist_widget->AddKey(addr.items);
+	}
+	return true;
 }
 
 bool
@@ -457,15 +460,15 @@ TestvdkForm::OnReloadClicked(VDKObject* sender)
 VDKObject* 
 TestvdkForm::CreateImage(VDKForm* owner)
 {
-  static char *tip = "This will be the new VDKBuilder 2.0 logo";
-  VDKBox* vbox = new VDKBox(owner);
-  // setting last arg as true embedds pixmap into an event box so
-  // will receive appropriate signals and can show tip
-  // see below on CreateScrolled()  another way where pixmap is
-  // explicitely embedded into an event box
-  VDKImage* image = new VDKImage(owner,"vitrurian.png",tip,true);
-  vbox->Add(image);
-  return vbox;
+	static char *tip = "This will be the new VDKBuilder 2.0 logo";
+	VDKBox* vbox = new VDKBox(owner);
+	// setting last arg as true embedds pixmap into an event box so
+	// will receive appropriate signals and can show tip
+	// see below on CreateScrolled()  another way where pixmap is
+	// explicitely embedded into an event box
+	VDKImage* image = new VDKImage(owner, "vitrurian.png", tip, true);
+	vbox->Add(image);
+	return vbox;
 }
 /*
   =========================
@@ -475,19 +478,19 @@ TestvdkForm::CreateImage(VDKForm* owner)
 VDKObject* 
 TestvdkForm::CreateScrolled(VDKForm* owner)
 {
-  static char *tip = 
-"Believe it or not, VDK original author \
-has flown more than 1500 hours on this airplane";
-  VDKFixed* fixed = new VDKFixed(owner);
-  VDKScrolled* scrolled = new VDKScrolled(owner);
-  scrolled->Usize = VDKPoint(250,200);
-  VDKEventBox* vbox = new VDKEventBox(owner);
-  VDKPixmap* pixmap = new VDKPixmap(owner,"f104.xpm");
-  vbox->SetTip(tip);
-  vbox->Add(pixmap);
-  scrolled->Add(vbox);
-  fixed->Add(scrolled,l_justify,0,0); 
-  return fixed;
+	static char *tip = 
+		"Believe it or not, VDK original author \
+		has flown more than 1500 hours on this airplane";
+	VDKFixed* fixed = new VDKFixed(owner);
+	VDKScrolled* scrolled = new VDKScrolled(owner);
+	scrolled->Usize = VDKPoint(250,200);
+	VDKEventBox* vbox = new VDKEventBox(owner);
+	VDKPixmap* pixmap = new VDKPixmap(owner, "f104.xpm");
+	vbox->SetTip(tip);
+	vbox->Add(pixmap);
+	scrolled->Add(vbox);
+	fixed->Add(scrolled,l_justify,0,0); 
+	return fixed;
 }
 /*
   =========================
@@ -737,21 +740,88 @@ static char* introduction =
 "\tMile Lazarovski</i>"
 "</span></span>";
 
+
+
+
+
+/*
+  all this to set size of docker
+  when undocked
+ */
+VDKPoint docker_size(0,0);
+bool docker_set = false;
+bool 
+TestvdkForm::OnDockButtonClicked(VDKObject* sender)
+{
+  if(sender == dockbutton)
+    {
+      if(!dockbox->Docked && !docker_set)
+	{
+	  dockbox->SetSize(docker_size.x,docker_size.y);
+	  docker_set = true;
+	}
+      dockbox->Docked = dockbox->Docked ? false: true;
+      dockbutton->Caption = dockbox->Docked ? "Undock me" : "Dock me";
+      if(dockbox->Docked) dockbox->DockForm()->Title = "Docked";
+    }
+  else if(sender == MenuItem1)
+    {
+     menu_dockbox->Docked = menu_dockbox->Docked ? false: true;
+     MenuItem1->Caption = menu_dockbox->Docked ? "Undock me" : "Dock me";
+    }
+  return true;
+}
+
+bool 
+TestvdkForm::OnRealizeDockbox(VDKObject* sender)
+{
+  VDKDockerBox* db = dynamic_cast<VDKDockerBox*>(sender);
+  if(db)
+    {
+      double w = GTK_WIDGET(db->WrappedWidget())->allocation.width;
+      double h = GTK_WIDGET(db->WrappedWidget())->allocation.height;
+      docker_size = VDKPoint((int) w,(int) h);
+    }
+  return true;
+}
+
 void
 TestvdkForm::GUISetup(void)
 {
   int t = 0;
   SetDefaultSize(VDKPoint(650,450));
   Title = "VDK 2.0.x Test";
+  // force to realize
   if(!GTK_WIDGET_REALIZED(Window()))
      gtk_widget_realize(Window());
+  // the main box
   hbox2 = new VDKBox(this,h_box);
-  Add(hbox2,2,1,1,0);
+  Add(hbox2,r_justify,true,true,2);
   hbox2->BorderWidth(5);
+  /*
+    makes a dockable box, connect it to realize signal
+    so we can know the allocated size, We use it
+    to set a reasonable dimension when undocked.
+  */
+  dockbox = new VDKDockerBox(this);
+  SignalConnect(dockbox,"realize",&TestvdkForm::OnRealizeDockbox);
   /*
     makes a new scrolled to be filled with list
+    and add it to dockable
   */
   VDKScrolled *scrolled = new VDKScrolled(Owner());
+  //scrolled->SetSize(150,300);
+  dockbox->Add(scrolled);
+  /*
+    makes a button box and add it to
+    dockable (with a separator in between
+  */
+  dockbox->Add(new VDKSeparator(this),l_justify,false,false,0);
+  dockbutton = new VDKCustomButton(this,"Dock me");
+  dockbox->Add(dockbutton,l_justify,false,false,0);
+  // add dockable to main box
+  hbox2->Add(dockbox,l_justify,true,true,0);
+  // makes test list
   testlist = new VDKTreeView(this,NULL,GTK_SELECTION_SINGLE);
   // makes model
   VDKTreeViewModel* model;
@@ -783,9 +853,10 @@ TestvdkForm::GUISetup(void)
   GtkTreeIter iter;
   if(model->Root(&iter))
     testlist->SelectNode(&iter);
+  // adds test list to scrolled
   scrolled->Add(testlist,l_justify,false,false,0);
-  hbox2->Add(scrolled);
 
+  // makes test frame
   testframe = new VDKFrame(this,NULL,v_box,shadow_etched_in);
   testframe->Shadow = shadow_etched_in;
   testframe->Align = c_justify;
@@ -823,10 +894,14 @@ TestvdkForm::GUISetup(void)
   eventbox->Add(introduce_vdk,l_justify,false,false,5);
   testframe->BorderWidth(5);
   // initial contents of testframe finished
-  hbox2->Add(testframe,0,1,1,0);
-  // sets main menu bar
+  // adds it to main box
+  hbox2->Add(testframe,r_justify,1,1,0);
+  // sets main menu bar (into a dockable box)
+  menu_dockbox = new VDKDockerBox(this);
   menubar = new VDKMenubar(this);
-  Add(menubar,0,0,0,0);
+  menubar->SetSize(200,-1);
+  menu_dockbox->Add(menubar,0,0,0,0);
+  Add(menu_dockbox,l_justify,false,false,0);
   MenuItem0 = new VDKMenuItem(this,"MenuItem0",mini_cfolder_xpm);
   MenuItem0->Caption = "_File...";
   MenuItem0->Checked = false;
@@ -847,6 +922,8 @@ TestvdkForm::GUISetup(void)
   quitMenu = new VDKMenuItem(this,"quitMenu",NULL);
   quitMenu->Caption = "_Quit";
   Menu0->Add(quitMenu,l_justify,1,1,0);
+  MenuItem1 = new VDKMenuItem(this,"Dock me");
+  menubar->Add(MenuItem1,l_justify,1,1,0);
 }
 /*
   main form setup
@@ -861,10 +938,17 @@ TestvdkForm::Setup(void)
 bool
 TestvdkForm::CanClose(void)
 {
-  bool result =  Application()->VDKMessageBox(
+/* For VDKMessageBox tests only - plm V 2.5.0
+  bool result = Application()->VDKMessageBox(
 					   "VDK \"The Visual Development Kit\"",
 					   "Really do you want quit VDK test program ?",
-					   VDK_ICONQUESTION | VDK_YESNO,NULL,NULL,5000) == VDK_IDYES;
+					   VDK_ICONQUESTION | VDK_YESNOCANCEL, 5000) == VDK_IDYES;
+*/
+  bool result = Application()->VDKMessageBox(
+					   "VDK \"The Visual Development Kit\"",
+					   "Really do you want quit VDK test program ?",
+					   VDK_ICONQUESTION | VDK_YESNO, 5000) == VDK_IDYES;
+//
   return result;
 
 }
