@@ -1,8 +1,13 @@
+
 #include <stdio.h>		// for printf()
 #include <iostream>
 #include <vdk/vdkstring.h>
 #include <vector>
 
+using std::vector;
+using std::cout;
+using std::endl;
+
 VDKString Funt(const VDKString& s)
 {
 	VDKString local(s);
@@ -11,7 +16,10 @@ VDKString Funt(const VDKString& s)
 
 void test1()
 {
-	VDKString A;
+	// cout seems to dislike NULL pointers...
+	//VDKString A;
+	VDKString A("");
+	
 	cout << "Default Constructor: VDKString A = " << A << endl;
 
 	VDKString copyofA = A;
@@ -32,23 +40,23 @@ void test1()
 	cout << "Prepending a char: C = VDKString(c) + C = " ;
 	C = VDKString(c) + C ;
 	cout << C << endl;
-
-	cout << "Appending a char to null string : A = copyofA + c = " ;
+	
+	VDKString ncopyofA;
+	cout << "Appending a char to null string : A = ncopyofA + c = " ;
 	cout.flush();
-	A = copyofA + VDKString(c) ;
+	A = ncopyofA + VDKString(c) ;
 	cout << A << endl;
 
-	cout << "Prepending a char to null string : A = c + copyofA =";
+	cout << "Prepending a char to null string : A = c + ncopyofA =";
 	cout.flush();
-	A = VDKString(c) + copyofA ;
+	A = VDKString(c) + ncopyofA ;
 	cout << A << endl;
 
-	cout << "Test of [] operator: B = " << B << 
-		" B[0] = " << B[0] << 
-		" B[1] = " << B[1] << 
-		" B[2] = " << B[2] << 
-		" B[20] = " << B[20] << 
-		endl;
+	cout << "Test of [] operator: B = " << B << endl;
+	cout << " B[0] = " << B[(unsigned int)0] << endl;
+	cout << " B[1] = " << B[(unsigned int)1] << endl;
+	cout << " B[2] = " << B[(unsigned int)2] << endl;
+	cout << " B[20] = " << B[(unsigned int)20] << endl;
 
 	cout << "B.c_str() = " ;
 	cout.flush();
@@ -64,26 +72,27 @@ void test1()
 	A = "goozy" + B ;
 	cout << A << endl;
 
-	cout << " VDKString(NULL) + const char* : C = copyofA + 'goozy' = ";
+	cout << " VDKString(NULL) + const char* : C = ncopyofA + 'goozy' = ";
 	cout.flush();
-	C = copyofA + "goozy";
+	C = ncopyofA + "goozy";
 	cout << C << endl;
 
-	cout << " const char* + VDKString(NULL)  : A = 'goozy' + copyofA = ";
+	cout << " const char* + VDKString(NULL)  : A = 'goozy' + ncopyofA = ";
 	cout.flush();
-	A = "goozy" + copyofA ;
+	A = "goozy" + ncopyofA ;
 	cout << A << endl;
 
-	cout << "Instantsiate a VDKString from a single character : ";
+	cout << "Instantiate a VDKString from a single character : ";
 
 	VDKString E('a');
 	cout << "E('a') = " << E << endl;
-
-	cout << "Instantsiate a VDKString from a null character : ";
+/*
+	cout << "Instantiate a VDKString from a null character : ";
 	VDKString F('\0');
 	cout << "F(NULL) = " << F << endl;
+*/
 	cout << "Assignment of a single character : ";
-	F = 'b';
+	VDKString F = 'b';
 	cout << "F = 'b' = " << F << endl;
 
 	cout << "A = " << A << endl;
@@ -122,9 +131,18 @@ void test1()
 	A = "9600,8,n,1";
 	cout << "A = '9600,8,n,1', A.GetPart(1, ',') = " << A.GetPart(1, ',') << endl;
 	A = "9600,8,n,1";
-	cout << "A = '9600,8,n,1', A.GetPart(0, ',') = " << A.GetPart(0, ',') << endl;
+	cout << "A = '9600,8,n,1', A.GetPart(2, ',') = " << A.GetPart(2, ',') << endl;
 	A = "9600,8,n,1";
-	cout << "A = '9600,8,n,1', A.GetPart(5, ',') = " << A.GetPart(5, ',') << endl;
+	cout << "A = '9600,8,n,1', A.GetPart(4, ',') = " << A.GetPart(4, ',') << endl;
+	// GetPart test
+	A = "9600#!#8#!#n#!#1";
+	// New CharCount test
+	cout << "A.CharCount(\"#!#\") = " << A.CharCount("#!#") << endl;
+	cout << "A = '9600#!#8#!#n#!#1', A.GetPart(1, \"#!#\") = " << A.GetPart(1, "#!#") << endl;
+	A = "9600#!#8#!#n#!#1";
+	cout << "A = '9600#!#8#!#n#!#1', A.GetPart(2, \"#!#\") = " << A.GetPart(2, "#!#") << endl;
+	A = "9600#!#8#!#n#!#1";
+	cout << "A = '9600#!#8#!#n#!#1', A.GetPart(4, \"#!#\") = " << A.GetPart(4, "#!#") << endl;
 	// GetFCharPos test
 	A = "9600,8,n,1";
 	cout << "A = '9600,8,n,1', A.GetFCharPos(',') = " << A.GetFCharPos(',') << endl;
@@ -160,7 +178,6 @@ void test1()
 	cout << "A.FormatDate('/', ENG_DATE, ENG_DATE) => A = " << A.FormatDate('/', ENG_DATE, ENG_DATE) << endl;
 }
 
-
 vector<VDKString> vectortest()
 {
 
@@ -194,7 +211,7 @@ vector<VDKString> vectortest()
 }
 
 
-void DumpVDKStringVector(const vector<VDKString>& A)
+void DumpVDKUStringVector(const vector<VDKString>& A)
 {
 
 	cout << "Reading the returned vector using an const iterator..." << endl;
@@ -213,7 +230,7 @@ void DumpVDKStringVector(const vector<VDKString>& A)
 void stltest()
 {
 	vector<VDKString> A = vectortest();
-	DumpVDKStringVector(A);
+	DumpVDKUStringVector(A);
 
 }
 
